.. pairwisedist documentation master file, created by
   sphinx-quickstart on Wed Jun 17 23:09:37 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

*pairwisedist* |release| documentation
=======================================

**Useful links:** `Documentation <https://guyteichman.github.io/pairwisedist>`_ |
`Source code <https://github.com/GuyTeichman/pairwisedist>`_ |
`Bug reports <https://github.com/GuyTeichman/pairwisedist/issues>`_ | |pipimage| | |travisci| | |downloads|

------


.. toctree::
   :maxdepth: 1
   :caption: About pairwisedist:

   What is pairwisedist? <readme>
   GitHub page <https://github.com/GuyTeichman/pairwisedist>
   authors


.. toctree::
   :maxdepth: 2
   :caption: How to use pairwisedist:

   installation
   user_guide
   api_reference

.. toctree::
   :maxdepth: 2
   :caption: Change history:

   history

Distance functions:
-------------------
.. autosummary::
  :toctree:
  :caption: Distance functions:

  pairwisedist.pairwisedist


.. toctree::
   :maxdepth: 1
   :caption: Indices and tables:

   genindex
   api_reference


.. |pipimage| image:: https://img.shields.io/pypi/v/pairwisedist.svg
        :target: https://pypi.python.org/pypi/pairwisedist
.. |downloads| image:: https://pepy.tech/badge/pairwisedist
        :target: https://pepy.tech/project/pairwisedist
..  |travisci| image:: https://travis-ci.org/GuyTeichman/pairwisedist.svg?branch=master
    :target: https://travis-ci.org/GuyTeichman/pairwisedist